@@ -9,9 +9,9 @@ from functools import wraps
 from textwrap import shorten
 from datetime import datetime
 
-DATEFORMAT_STD = "%Y-%m-%d %H:%M:%S"
+DATEFORMAT_STD = "%Y-%m-%d %H:%M:%S,%f"
 DATEFORMAT_DEV = "%H:%M:%S"
-DATEFORMAT_FILE = "%Y-%m-%d_%H-%M-%S"
+DATEFORMAT_FILE = "%Y-%m-%d_%H-%M-%S,%f"
 
 
 def pathmaker(first_segment, *in_path_segments, rev=False):
